==> foundation-datepicker-1.5.0.tgz: foundation-datepicker/README.md <==
# Installation
> `npm install --save @types/foundation-datepicker`

# Summary
This package contains type definitions for foundation-datepicker (https://github.com/najlepsiwebdesigner/foundation-datepicker).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/foundation-datepicker.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/foundation-datepicker/index.d.ts)
````ts
// Type definitions for foundation-datepicker 1.5
// Project: https://github.com/najlepsiwebdesigner/foundation-datepicker
// Definitions by: Matt Smith <https://github.com/mattsmithcode>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types="jquery" />

declare namespace FoundationDatepicker {
    interface Event extends JQuery.Event {
        date: Date;
    }

    interface OutOfRangeEvent extends Event {
        startDate: Date;
        endDate: Date;
    }

    interface Settings {
        appendTo?: JQuery.Selector | JQuery.htmlString | JQuery.TypeOrArray<Element | DocumentFragment> | JQuery;
        autoShow?: boolean;
        autoclose?: boolean;
        calendarWeeks?: boolean;
        closeButton?: boolean;
        closeIcon?: string;
        datesDisabled?: string[];
        daysOfWeekDisabled?: number[];
        disableDblClickSelection?: boolean;
        endDate?: Date;
        faCSSprefix?: string;
        forceParse?: boolean;
        format?: string;
        initialDate?: string;
        keyboardNavigation?: boolean;
        language?: string;
        leftArrow?: string;
        maxView?: 'decade' | 'year' | 'month' | 'day' | 'hour' | number;
        minView?: 'decade' | 'year' | 'month' | 'day' | 'hour' | number;
        minuteStep?: number;
        nonMilitaryTime?: boolean;
        onRender?: (date: Date) => string;
        pickTime?: boolean;
        rightArrow?: string;
        startDate?: Date;
        startView?: 'decade' | 'year' | 'month' | 'day' | 'hour' | number;
        todayBtn?: boolean;
        todayHighlight?: boolean;
        weekStart?: number;
    }
}

interface JQuery<TElement = HTMLElement> {
    fdatepicker(option?: FoundationDatepicker.Settings | 'show' | 'hide' | 'place'): JQuery;
    fdatepicker(option: 'update', value: string | Date): JQuery;
    on(events: 'show' | 'hide' | 'changeDate', handler: (eventObject: FoundationDatepicker.Event) => void): JQuery;
    on(events: 'outOfRange', handler: (eventObject: FoundationDatepicker.OutOfRangeEvent) => void): JQuery;
}

````

### Additional Details
 * Last updated: Sat, 21 May 2022 19:31:44 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Matt Smith](https://github.com/mattsmithcode).

==> foundation-datepicker-1.5.1.tgz: foundation-datepicker/README.md <==
# Installation
> `npm install --save @types/foundation-datepicker`

# Summary
This package contains type definitions for foundation-datepicker (https://github.com/najlepsiwebdesigner/foundation-datepicker).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/foundation-datepicker.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/foundation-datepicker/index.d.ts)
````ts
// Type definitions for foundation-datepicker 1.5
// Project: https://github.com/najlepsiwebdesigner/foundation-datepicker
// Definitions by: Matt Smith <https://github.com/mattsmithcode>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types="jquery" />

declare namespace FoundationDatepicker {
    interface Event extends JQuery.Event {
        date: Date;
    }

    interface OutOfRangeEvent extends Event {
        startDate: Date;
        endDate: Date;
    }

    interface Settings {
        appendTo?: JQuery.Selector | JQuery.htmlString | JQuery.TypeOrArray<Element | DocumentFragment> | JQuery;
        autoShow?: boolean;
        autoclose?: boolean;
        calendarWeeks?: boolean;
        closeButton?: boolean;
        closeIcon?: string;
        datesDisabled?: string[];
        daysOfWeekDisabled?: number[];
        disableDblClickSelection?: boolean;
        endDate?: Date;
        faCSSprefix?: string;
        forceParse?: boolean;
        format?: string;
        initialDate?: string;
        keyboardNavigation?: boolean;
        language?: string;
        leftArrow?: string;
        maxView?: "decade" | "year" | "month" | "day" | "hour" | number;
        minView?: "decade" | "year" | "month" | "day" | "hour" | number;
        minuteStep?: number;
        nonMilitaryTime?: boolean;
        onRender?: (date: Date) => string;
        pickTime?: boolean;
        rightArrow?: string;
        startDate?: Date;
        startView?: "decade" | "year" | "month" | "day" | "hour" | number;
        todayBtn?: boolean;
        todayHighlight?: boolean;
        weekStart?: number;
    }
}

interface JQuery<TElement = HTMLElement> {
    fdatepicker(option?: FoundationDatepicker.Settings | "show" | "hide" | "place"): JQuery;
    fdatepicker(option: "update", value: string | Date): JQuery;
    on(events: "show" | "hide" | "changeDate", handler: (eventObject: FoundationDatepicker.Event) => void): JQuery;
    on(events: "outOfRange", handler: (eventObject: FoundationDatepicker.OutOfRangeEvent) => void): JQuery;
}

````

### Additional Details
 * Last updated: Thu, 14 Sep 2023 15:26:41 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Matt Smith](https://github.com/mattsmithcode).
